==> qtjambi-quick-5.15.4-sources.jar: io/qt/quick/QQuickTextDocument.java <==
package io.qt.quick;


/**
 * <p>Access to the QTextDocument of QQuickTextEdit</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qquicktextdocument.html">QQuickTextDocument</a></p>
 */
public class QQuickTextDocument extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QQuickTextDocument.class);
    
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qquicktextdocument.html#QQuickTextDocument">QQuickTextDocument::QQuickTextDocument(QQuickItem*)</a></p>
     */
    public QQuickTextDocument(io.qt.quick.QQuickItem parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QQuickTextDocument instance, io.qt.quick.QQuickItem parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qquicktextdocument.html#textDocument">QQuickTextDocument::textDocument()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.gui.QTextDocument textDocument(){
        return textDocument_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QTextDocument textDocument_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QQuickTextDocument(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-quick-6.2.10-sources.jar: io/qt/quick/QQuickTextDocument.java <==
package io.qt.quick;


/**
 * <p>Access to the QTextDocument of QQuickTextEdit</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qquicktextdocument.html">QQuickTextDocument</a></p>
 */
public class QQuickTextDocument extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QQuickTextDocument.class);
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qquicktextdocument.html#QQuickTextDocument">QQuickTextDocument::QQuickTextDocument(QQuickItem*)</a></p>
     */
    public QQuickTextDocument(io.qt.quick.QQuickItem parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QQuickTextDocument instance, io.qt.quick.QQuickItem parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qquicktextdocument.html#textDocument">QQuickTextDocument::textDocument()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.gui.QTextDocument textDocument(){
        return textDocument_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QTextDocument textDocument_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QQuickTextDocument(QPrivateConstructor p) { super(p); } 
    
}
